%EITC.m: Simulates EITC and produces simulation data for comparison with
% Eissa-Liebman (1996)

gensperyear=100;
gens=gensperyear*60;
step=1/gens;
time=0:step:1;
gens=gens+1;

gamma=4; %preference parameter in the utility function
e0=1;e1=.581; %intercept and slope of age-productivity profile.

%calibration of mu and hbar - straight from Rogerson-Wallenius code
h0t=.45; %target value for hmmax, so that 45% of discretionary time per week is worked
lamt=.758;%target value for share of lifetime working; comes from Eissa-Liebman data of 73.8% LFP
taut=.508; %initial average tax rate = 50.8% 
taun=.436; %new tax = 43.6% 
hbar=((e0*(1-lamt)+e1*lamt)/e0)^(1/gamma)*h0t*gamma/(1+gamma); %formula to
%calibrate hbar
mua=e0/h0t^gamma/(e0*h0t/(1/gamma+2).*(1-(1-lamt).^(1/gamma+2))-e0*hbar/2*(1-(1-lamt).^2)); %not sure what this is
mu=(1-taut)*e0/h0t^gamma/...
    (h0t/e0^(1/gamma)/(1/gamma+2)/(e1-e0).*((e0*(1-lamt)+e1*lamt).^(1/gamma+2)-e0^(1/gamma+2))-...
    hbar/2/(e1-e0).*((e0*(1-lamt)+e1*lamt).^2-e0^2)); %Really ugly expression for alpha (they call mu here, but alpha in paper)

% wage ratio
vec=0:.0001:lamt;
eproft=e0*(1-vec)+e1*vec;
hproft=h0t*((1-vec)+e1/e0*vec).^(1/gamma);
wproft=eproft.*(hproft-hbar)./hproft;
s=size(vec);
s=s(2);
wratio=wproft(s)/wproft(1)

% simulate elasticities
el_gens=6000; %gens for computing elasticities
[intensive_frisch participation_frisch aggregate_frisch] = SimFrischElasticity(hbar,mu,e0,e1,gamma,taut,taut-.01,el_gens);
h1=RWSim(hbar,mu,e0,e1,gamma,taut,el_gens);
h2=RWSim(hbar,mu,e0,e1,gamma,taut-.01,el_gens);
h1=1/el_gens*sum(h1);
h2=1/el_gens*sum(h2);
aggregate_hicksian=log(h2/h1)/log((1-taut+.01)/(1-taut));
h1=RWSim(hbar,mu,e0,e1,gamma,taut,el_gens);
h2=RWSim(hbar,mu,e0,e1,gamma,taut-.01,el_gens);
h1=(h1>0);
h2=(h2>0);
h1=1/el_gens*sum(h1);
h2=1/el_gens*sum(h2);
participation_hicksian=log(h2/h1)/log((1-taut+.01)/(1-taut));
h1=RWSim(hbar,mu,e0,e1,gamma,taut,el_gens);
h2=RWSim(hbar,mu,e0,e1,gamma,taut-.01,el_gens);
h2(h1==0)=0;
h1=1/el_gens*sum(h1);
h2=1/el_gens*sum(h2);
intensive_hicksian=log(h2/h1)/log((1-taut+.01)/(1-taut));


%run the EITC OLG Sim to get new asset profiles for change from tau to taun
[hoursprof lfpprof nhoursprof nlfpprof annuallfp maxhours minhours] = EITCSimOLG2(hbar,mu,e0,e1,gamma,taut,taun,gensperyear);

time2=[-60:step*60:60];
%version 2 goes from -60 years to 60 years with change at zero
nhoursprof2=[hoursprof nhoursprof(2:gens)];
hoursprof2=[hoursprof hoursprof(2:gens)];
nlfpprof2=[lfpprof nlfpprof(2:gens)];
lfpprof2=[lfpprof lfpprof(2:gens)];
save('eitc-point25.mat');

%output in EITC-binned.csv and EITC-binned.csv
outmat=[time2' lfpprof2' nlfpprof2'];
csvwrite('EITC-point25-unbinned.csv', outmat);
csvwrite('EITC-point25-binned.csv', annuallfp);

intensive_frisch
participation_frisch
aggregate_frisch
intensive_hicksian
participation_hicksian
aggregate_hicksian
hbar
mu
gamma
e1
maxhours
minhours
